--***************************************************************
--* File         : RESFIL.vhd                                   *
--* Created      : time-stamp: <09/04/25 14:52:12 kawasan>      *
--* Modified     : Time-stamp: <09/04/25 15:44:32 kawasan>      *
--*                                                             *
--* Reset signal filter                                         *
--*                                                             *
--* Copyright 2009 Osamu Kawashima. all rights reserved         *
--***************************************************************

library ieee;
use ieee.std_logic_1164.all;

entity RESFIL is
	generic (
		FILTER_SIZE     : positive := 3
	);
	port (
		SYSCLK          : in    std_logic;
		RESET_I         : in    std_logic;
		RESET_O         : out   std_logic
	);
end RESFIL;

architecture RTL of RESFIL is

	constant ZERO32         : std_logic_vector(31 downto 0) := (others=>'0');
	constant ONE32          : std_logic_vector(31 downto 0) := (others=>'1');

	signal reset_tmp        : std_logic_vector(FILTER_SIZE-1 downto 0) := (others=>'1');

begin

	process (SYSCLK)
	begin
		if SYSCLK'event and SYSCLK='1' then
			reset_tmp <= reset_tmp(reset_tmp'left-1 downto 0) & RESET_I;
		end if;
	end process;

	RESET_O <= '1' when reset_tmp=ONE32(reset_tmp'left downto 0) else '0';

end RTL;
