--***************************************************************
--* File         : TB_RESFIL.vhd                                *
--* Created      : time-stamp: <09/04/25 15:07:22 kawasan>      *
--* Modified     : Time-stamp: <09/04/25 15:41:33 kawasan>      *
--*								*
--* Test-Bench                                                  *
--*								*
--* Copyright 2009 Osamu Kawashima. all rights reserved		*
--***************************************************************

library ieee;
use ieee.std_logic_1164.all;
use ieee.std_logic_unsigned.all;

use std.textio.all;
use ieee.std_logic_textio.all;

entity TB_RESFIL is
	generic (
		FILTER_SIZE     : positive := 3
	);
end;

architecture behavior of TB_RESFIL is
    
	component RESFIL
	generic (
		FILTER_SIZE     : positive := 3
	);
	port (
		SYSCLK          : in    std_logic;
		RESET_I         : in    std_logic;
		RESET_O         : out   std_logic
	);
	end component;

	constant ZERO32         : std_logic_vector(31 downto 0) := (others=>'0');
	constant ONE32          : std_logic_vector(31 downto 0) := (others=>'1');

	constant WT1            : Time := 10 ns;
	constant WT_DELAY       : Time := 1 ns;
	constant WT_IDLE        : Time := 100 ns;
	constant CLK_CYCLE      : Time := 21 ns;	-- about 48MHz

	signal SYSCLK           : std_logic := '0';
	signal RESET_I          : std_logic := '1';
	signal RESET_O          : std_logic := '0';

begin
    
	uRESFIL : RESFIL
	generic map (
		FILTER_SIZE     => 3
	)
	port map (
		SYSCLK          => SYSCLK,
		RESET_I         => RESET_I,
		RESET_O         => RESET_O
	);

	process begin
		wait for CLK_CYCLE/2;
		SYSCLK <= not SYSCLK;
	end process;

	process
		variable ln         : line;
	begin
		-- Reset
		wait for WT_IDLE+WT_DELAY;
		RESET_I <= '0';
		write(ln, string'("--- Release Reset. ---"));
		writeline(output, ln);
		wait for WT_IDLE;

		-- Noise
		RESET_I <= '1';
		wait for WT_DELAY;
		RESET_I <= '0';
		wait for WT_IDLE;

		-- Reset
		RESET_I <= '1';
		wait for WT_IDLE+WT_DELAY;
		RESET_I <= '0';
		wait for WT_IDLE;

		-- End
		write(ln, string'("--- End of Test-Bench. ---"));
		writeline(output, ln);
		wait;
	end process;

end behavior;
